==> jc-1.4.0.tar.gz: soot/coffi/ByteCode.h <==
// class soot.coffi.ByteCode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 674790b56860ca91 soot_coffi_ByteCode

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_ByteCode_H_
#define _JC_soot_coffi_ByteCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_ByteCode$sub_refs	_jc_soot_coffi_ByteCode$sub_refs;
typedef struct _jc_soot_coffi_ByteCode$sub_nonrefs	_jc_soot_coffi_ByteCode$sub_nonrefs;
typedef struct _jc_soot_coffi_ByteCode$refs	_jc_soot_coffi_ByteCode$refs;
typedef struct _jc_soot_coffi_ByteCode$nonrefs	_jc_soot_coffi_ByteCode$nonrefs;
typedef struct _jc_soot_coffi_ByteCode$object	_jc_soot_coffi_ByteCode$object;

typedef struct _jc_soot_coffi_ByteCode$fields_struct	_jc_soot_coffi_ByteCode$fields_struct;
typedef const struct _jc_soot_coffi_ByteCode$vmethods	_jc_soot_coffi_ByteCode$vmethods;
typedef const struct _jc_soot_coffi_ByteCode$vtable	_jc_soot_coffi_ByteCode$vtable;
typedef const struct _jc_soot_coffi_ByteCode$vtype	_jc_soot_coffi_ByteCode$vtype;

// Class fields structure
struct _jc_soot_coffi_ByteCode$fields_struct {
	jint	AALOAD;
	jint	AASTORE;
	jint	ACONST__5fNULL;
	jint	ALOAD;
	jint	ALOAD__5f0;
	jint	ALOAD__5f1;
	jint	ALOAD__5f2;
	jint	ALOAD__5f3;
	jint	ANEWARRAY;
	jint	ARETURN;
	jint	ARRAYLENGTH;
	jint	ASTORE;
	jint	ASTORE__5f0;
	jint	ASTORE__5f1;
	jint	ASTORE__5f2;
	jint	ASTORE__5f3;
	jint	ATHROW;
	jint	BALOAD;
	jint	BASTORE;
	jint	BIPUSH;
	jint	BREAKPOINT;
	jint	CALOAD;
	jint	CASTORE;
	jint	CHECKCAST;
	jint	D2F;
	jint	D2I;
	jint	D2L;
	jint	DADD;
	jint	DALOAD;
	jint	DASTORE;
	jint	DCMPG;
	jint	DCMPL;
	jint	DCONST__5f0;
	jint	DCONST__5f1;
	jint	DDIV;
	jint	DLOAD;
	jint	DLOAD__5f0;
	jint	DLOAD__5f1;
	jint	DLOAD__5f2;
	jint	DLOAD__5f3;
	jint	DMUL;
	jint	DNEG;
	jint	DREM;
	jint	DRETURN;
	jint	DSTORE;
	jint	DSTORE__5f0;
	jint	DSTORE__5f1;
	jint	DSTORE__5f2;
	jint	DSTORE__5f3;
	jint	DSUB;
	jint	DUP;
	jint	DUP2;
	jint	DUP2__5fX1;
	jint	DUP2__5fX2;
	jint	DUP__5fX1;
	jint	DUP__5fX2;
	jint	F2D;
	jint	F2I;
	jint	F2L;
	jint	FADD;
	jint	FALOAD;
	jint	FASTORE;
	jint	FCMPG;
	jint	FCMPL;
	jint	FCONST__5f0;
	jint	FCONST__5f1;
	jint	FCONST__5f2;
	jint	FDIV;
	jint	FLOAD;
	jint	FLOAD__5f0;
	jint	FLOAD__5f1;
	jint	FLOAD__5f2;
	jint	FLOAD__5f3;
	jint	FMUL;
	jint	FNEG;
	jint	FREM;
	jint	FRETURN;
	jint	FSTORE;
	jint	FSTORE__5f0;
	jint	FSTORE__5f1;
	jint	FSTORE__5f2;
	jint	FSTORE__5f3;
	jint	FSUB;
	jint	GETFIELD;
	jint	GETSTATIC;
	jint	GOTO;
	jint	GOTO__5fW;
	jint	I2D;
	jint	I2F;
	jint	I2L;
	jint	IADD;
	jint	IALOAD;
	jint	IAND;
	jint	IASTORE;
	jint	ICONST__5f0;
	jint	ICONST__5f1;
	jint	ICONST__5f2;
	jint	ICONST__5f3;
	jint	ICONST__5f4;
	jint	ICONST__5f5;
	jint	ICONST__5fM1;
	jint	IDIV;
	jint	IFEQ;
	jint	IFGE;
	jint	IFGT;
	jint	IFLE;
	jint	IFLT;
	jint	IFNE;
	jint	IFNONNULL;
	jint	IFNULL;
	jint	IF__5fACMPEQ;
	jint	IF__5fACMPNE;
	jint	IF__5fICMPEQ;
	jint	IF__5fICMPGE;
	jint	IF__5fICMPGT;
	jint	IF__5fICMPLE;
	jint	IF__5fICMPLT;
	jint	IF__5fICMPNE;
	jint	IINC;
	jint	ILOAD;
	jint	ILOAD__5f0;
	jint	ILOAD__5f1;
	jint	ILOAD__5f2;
	jint	ILOAD__5f3;
	jint	IMUL;
	jint	INEG;
	jint	INSTANCEOF;
	jint	INT2BYTE;
	jint	INT2CHAR;
	jint	INT2SHORT;
	jint	INVOKEINTERFACE;
	jint	INVOKENONVIRTUAL;
	jint	INVOKESTATIC;
	jint	INVOKEVIRTUAL;
	jint	IOR;
	jint	IREM;
	jint	IRETURN;
	jint	ISHL;
	jint	ISHR;
	jint	ISTORE;
	jint	ISTORE__5f0;
	jint	ISTORE__5f1;
	jint	ISTORE__5f2;
	jint	ISTORE__5f3;
	jint	ISUB;
	jint	IUSHR;
	jint	IXOR;
	jint	JSR;
	jint	JSR__5fW;
	jint	L2D;
	jint	L2F;
	jint	L2I;
	jint	LADD;
	jint	LALOAD;
	jint	LAND;
	jint	LASTORE;
	jint	LCMP;
	jint	LCONST__5f0;
	jint	LCONST__5f1;
	jint	LDC1;
	jint	LDC2;
	jint	LDC2W;
	jint	LDIV;
	jint	LLOAD;
	jint	LLOAD__5f0;
	jint	LLOAD__5f1;
	jint	LLOAD__5f2;
	jint	LLOAD__5f3;
	jint	LMUL;
	jint	LNEG;
	jint	LOOKUPSWITCH;
	jint	LOR;
	jint	LREM;
	jint	LRETURN;
	jint	LSHL;
	jint	LSHR;
	jint	LSTORE;
	jint	LSTORE__5f0;
	jint	LSTORE__5f1;
	jint	LSTORE__5f2;
	jint	LSTORE__5f3;
	jint	LSUB;
	jint	LUSHR;
	jint	LXOR;
	jint	MONITORENTER;
	jint	MONITOREXIT;
	jint	MULTIANEWARRAY;
	jint	NEW;
	jint	NEWARRAY;
	jint	NOP;
	jint	POP;
	jint	POP2;
	jint	PUTFIELD;
	jint	PUTSTATIC;
	jint	RET;
	jint	RETURN;
	jint	RET__5fW;
	jint	SALOAD;
	jint	SASTORE;
	jint	SIPUSH;
	jint	SWAP;
	jint	TABLESWITCH;
	jint	WIDE;
};
extern _jc_soot_coffi_ByteCode$fields_struct _jc_soot_coffi_ByteCode$class_fields;

// Constructors
extern void _jc_soot_coffi_ByteCode$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_ByteCode$object *);

// Virtual methods
extern void _jc_soot_coffi_ByteCode$method$build$e74caa86bbc26d02(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, struct _jc_soot_coffi_Instruction$object *);
extern struct _jc_soot_coffi_Instruction$object *_jc_soot_coffi_ByteCode$method$disassemble__5fbytecode$2e78e51b084a1588(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, struct _jc_byte_array *, jint);
extern struct _jc_soot_coffi_Instruction$object *_jc_soot_coffi_ByteCode$method$locateInst$5f9f03cfba31ce96(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, jint);
extern struct _jc_soot_coffi_Instruction$object *_jc_soot_coffi_ByteCode$method$locateInstr$c91b71ab556adcaa(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_ByteCode$method_info$build$e74caa86bbc26d02;
extern _jc_method _jc_soot_coffi_ByteCode$method_info$disassemble__5fbytecode$2e78e51b084a1588;
extern _jc_method _jc_soot_coffi_ByteCode$method_info$locateInst$5f9f03cfba31ce96;
extern _jc_method _jc_soot_coffi_ByteCode$method_info$locateInstr$c91b71ab556adcaa;

// Static methods
extern void _jc_soot_coffi_ByteCode$method$showCode$3ad5a7131b9ec32a(_jc_env *, struct _jc_soot_coffi_Instruction$object *, jint, struct _jc_object_array *);
extern void _jc_soot_coffi_ByteCode$method$showCode$e4e094f1dfcabcea(_jc_env *, struct _jc_soot_coffi_Instruction$object *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_soot_coffi_ByteCode$vmethods {
	void	(*build$e74caa86bbc26d02)(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, struct _jc_soot_coffi_Instruction$object *);
	struct _jc_soot_coffi_Instruction$object	*(*disassemble__5fbytecode$2e78e51b084a1588)(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, struct _jc_byte_array *, jint);
	struct _jc_soot_coffi_Instruction$object	*(*locateInst$5f9f03cfba31ce96)(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, jint);
	struct _jc_soot_coffi_Instruction$object	*(*locateInstr$c91b71ab556adcaa)(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, jint, jint, jint);
};

// Vtable
struct _jc_soot_coffi_ByteCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_ByteCode$vmethods	soot_coffi_ByteCode;
};

// Vtype
struct _jc_soot_coffi_ByteCode$vtype {
	_jc_type			type;
	_jc_soot_coffi_ByteCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_ByteCode$sub_refs {
	_jc_object_array	*instructions;
};

// Reference instance fields (object)
struct _jc_soot_coffi_ByteCode$refs {
    _jc_soot_coffi_ByteCode$sub_refs	soot_coffi_ByteCode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_ByteCode$sub_nonrefs {
	jint	icount;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_ByteCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_ByteCode$sub_nonrefs	soot_coffi_ByteCode;
};

// Object instance structure
struct _jc_soot_coffi_ByteCode$object {
	_jc_soot_coffi_ByteCode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_ByteCode$vtype	*vtype;
	_jc_soot_coffi_ByteCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_ByteCode$vtype _jc_soot_coffi_ByteCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_ByteCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_ByteCode$class_object;

#endif	/* _JC_soot_coffi_ByteCode_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/ByteCode.h <==
// class soot.coffi.ByteCode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 674790b56860ca91 soot_coffi_ByteCode

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_ByteCode_H_
#define _JC_soot_coffi_ByteCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_ByteCode$sub_refs	_jc_soot_coffi_ByteCode$sub_refs;
typedef struct _jc_soot_coffi_ByteCode$sub_nonrefs	_jc_soot_coffi_ByteCode$sub_nonrefs;
typedef struct _jc_soot_coffi_ByteCode$refs	_jc_soot_coffi_ByteCode$refs;
typedef struct _jc_soot_coffi_ByteCode$nonrefs	_jc_soot_coffi_ByteCode$nonrefs;
typedef struct _jc_soot_coffi_ByteCode$object	_jc_soot_coffi_ByteCode$object;

typedef struct _jc_soot_coffi_ByteCode$fields_struct	_jc_soot_coffi_ByteCode$fields_struct;
typedef const struct _jc_soot_coffi_ByteCode$vmethods	_jc_soot_coffi_ByteCode$vmethods;
typedef const struct _jc_soot_coffi_ByteCode$vtable	_jc_soot_coffi_ByteCode$vtable;
typedef const struct _jc_soot_coffi_ByteCode$vtype	_jc_soot_coffi_ByteCode$vtype;

// Class fields structure
struct _jc_soot_coffi_ByteCode$fields_struct {
	jint	AALOAD;
	jint	AASTORE;
	jint	ACONST__5fNULL;
	jint	ALOAD;
	jint	ALOAD__5f0;
	jint	ALOAD__5f1;
	jint	ALOAD__5f2;
	jint	ALOAD__5f3;
	jint	ANEWARRAY;
	jint	ARETURN;
	jint	ARRAYLENGTH;
	jint	ASTORE;
	jint	ASTORE__5f0;
	jint	ASTORE__5f1;
	jint	ASTORE__5f2;
	jint	ASTORE__5f3;
	jint	ATHROW;
	jint	BALOAD;
	jint	BASTORE;
	jint	BIPUSH;
	jint	BREAKPOINT;
	jint	CALOAD;
	jint	CASTORE;
	jint	CHECKCAST;
	jint	D2F;
	jint	D2I;
	jint	D2L;
	jint	DADD;
	jint	DALOAD;
	jint	DASTORE;
	jint	DCMPG;
	jint	DCMPL;
	jint	DCONST__5f0;
	jint	DCONST__5f1;
	jint	DDIV;
	jint	DLOAD;
	jint	DLOAD__5f0;
	jint	DLOAD__5f1;
	jint	DLOAD__5f2;
	jint	DLOAD__5f3;
	jint	DMUL;
	jint	DNEG;
	jint	DREM;
	jint	DRETURN;
	jint	DSTORE;
	jint	DSTORE__5f0;
	jint	DSTORE__5f1;
	jint	DSTORE__5f2;
	jint	DSTORE__5f3;
	jint	DSUB;
	jint	DUP;
	jint	DUP2;
	jint	DUP2__5fX1;
	jint	DUP2__5fX2;
	jint	DUP__5fX1;
	jint	DUP__5fX2;
	jint	F2D;
	jint	F2I;
	jint	F2L;
	jint	FADD;
	jint	FALOAD;
	jint	FASTORE;
	jint	FCMPG;
	jint	FCMPL;
	jint	FCONST__5f0;
	jint	FCONST__5f1;
	jint	FCONST__5f2;
	jint	FDIV;
	jint	FLOAD;
	jint	FLOAD__5f0;
	jint	FLOAD__5f1;
	jint	FLOAD__5f2;
	jint	FLOAD__5f3;
	jint	FMUL;
	jint	FNEG;
	jint	FREM;
	jint	FRETURN;
	jint	FSTORE;
	jint	FSTORE__5f0;
	jint	FSTORE__5f1;
	jint	FSTORE__5f2;
	jint	FSTORE__5f3;
	jint	FSUB;
	jint	GETFIELD;
	jint	GETSTATIC;
	jint	GOTO;
	jint	GOTO__5fW;
	jint	I2D;
	jint	I2F;
	jint	I2L;
	jint	IADD;
	jint	IALOAD;
	jint	IAND;
	jint	IASTORE;
	jint	ICONST__5f0;
	jint	ICONST__5f1;
	jint	ICONST__5f2;
	jint	ICONST__5f3;
	jint	ICONST__5f4;
	jint	ICONST__5f5;
	jint	ICONST__5fM1;
	jint	IDIV;
	jint	IFEQ;
	jint	IFGE;
	jint	IFGT;
	jint	IFLE;
	jint	IFLT;
	jint	IFNE;
	jint	IFNONNULL;
	jint	IFNULL;
	jint	IF__5fACMPEQ;
	jint	IF__5fACMPNE;
	jint	IF__5fICMPEQ;
	jint	IF__5fICMPGE;
	jint	IF__5fICMPGT;
	jint	IF__5fICMPLE;
	jint	IF__5fICMPLT;
	jint	IF__5fICMPNE;
	jint	IINC;
	jint	ILOAD;
	jint	ILOAD__5f0;
	jint	ILOAD__5f1;
	jint	ILOAD__5f2;
	jint	ILOAD__5f3;
	jint	IMUL;
	jint	INEG;
	jint	INSTANCEOF;
	jint	INT2BYTE;
	jint	INT2CHAR;
	jint	INT2SHORT;
	jint	INVOKEINTERFACE;
	jint	INVOKENONVIRTUAL;
	jint	INVOKESTATIC;
	jint	INVOKEVIRTUAL;
	jint	IOR;
	jint	IREM;
	jint	IRETURN;
	jint	ISHL;
	jint	ISHR;
	jint	ISTORE;
	jint	ISTORE__5f0;
	jint	ISTORE__5f1;
	jint	ISTORE__5f2;
	jint	ISTORE__5f3;
	jint	ISUB;
	jint	IUSHR;
	jint	IXOR;
	jint	JSR;
	jint	JSR__5fW;
	jint	L2D;
	jint	L2F;
	jint	L2I;
	jint	LADD;
	jint	LALOAD;
	jint	LAND;
	jint	LASTORE;
	jint	LCMP;
	jint	LCONST__5f0;
	jint	LCONST__5f1;
	jint	LDC1;
	jint	LDC2;
	jint	LDC2W;
	jint	LDIV;
	jint	LLOAD;
	jint	LLOAD__5f0;
	jint	LLOAD__5f1;
	jint	LLOAD__5f2;
	jint	LLOAD__5f3;
	jint	LMUL;
	jint	LNEG;
	jint	LOOKUPSWITCH;
	jint	LOR;
	jint	LREM;
	jint	LRETURN;
	jint	LSHL;
	jint	LSHR;
	jint	LSTORE;
	jint	LSTORE__5f0;
	jint	LSTORE__5f1;
	jint	LSTORE__5f2;
	jint	LSTORE__5f3;
	jint	LSUB;
	jint	LUSHR;
	jint	LXOR;
	jint	MONITORENTER;
	jint	MONITOREXIT;
	jint	MULTIANEWARRAY;
	jint	NEW;
	jint	NEWARRAY;
	jint	NOP;
	jint	POP;
	jint	POP2;
	jint	PUTFIELD;
	jint	PUTSTATIC;
	jint	RET;
	jint	RETURN;
	jint	RET__5fW;
	jint	SALOAD;
	jint	SASTORE;
	jint	SIPUSH;
	jint	SWAP;
	jint	TABLESWITCH;
	jint	WIDE;
};
extern _jc_soot_coffi_ByteCode$fields_struct _jc_soot_coffi_ByteCode$class_fields;

// Constructors
extern void _jc_soot_coffi_ByteCode$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_ByteCode$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_coffi_ByteCode$method$build$e74caa86bbc26d02(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_coffi_Instruction$object *_jc_soot_coffi_ByteCode$method$disassemble__5fbytecode$2e78e51b084a1588(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern struct _jc_soot_coffi_Instruction$object *_jc_soot_coffi_ByteCode$method$locateInst$5f9f03cfba31ce96(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_soot_coffi_Instruction$object *_jc_soot_coffi_ByteCode$method$locateInstr$c91b71ab556adcaa(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_ByteCode$method_info$build$e74caa86bbc26d02;
extern _jc_method _jc_soot_coffi_ByteCode$method_info$disassemble__5fbytecode$2e78e51b084a1588;
extern _jc_method _jc_soot_coffi_ByteCode$method_info$locateInst$5f9f03cfba31ce96;
extern _jc_method _jc_soot_coffi_ByteCode$method_info$locateInstr$c91b71ab556adcaa;

// Static methods
extern void _jc_soot_coffi_ByteCode$method$showCode$3ad5a7131b9ec32a(_jc_env *, struct _jc_soot_coffi_Instruction$object *, jint, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_ByteCode$method$showCode$e4e094f1dfcabcea(_jc_env *, struct _jc_soot_coffi_Instruction$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_ByteCode$vmethods {
	void	(*build$e74caa86bbc26d02)(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
	struct _jc_soot_coffi_Instruction$object	*(*disassemble__5fbytecode$2e78e51b084a1588)(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	struct _jc_soot_coffi_Instruction$object	*(*locateInst$5f9f03cfba31ce96)(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, jint) _JC_JCNI_ATTR;
	struct _jc_soot_coffi_Instruction$object	*(*locateInstr$c91b71ab556adcaa)(_jc_env *, struct _jc_soot_coffi_ByteCode$object *, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_ByteCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_ByteCode$vmethods	soot_coffi_ByteCode;
};

// Vtype
struct _jc_soot_coffi_ByteCode$vtype {
	_jc_type			type;
	_jc_soot_coffi_ByteCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_ByteCode$sub_refs {
	_jc_object_array	*instructions;
};

// Reference instance fields (object)
struct _jc_soot_coffi_ByteCode$refs {
    _jc_soot_coffi_ByteCode$sub_refs	soot_coffi_ByteCode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_ByteCode$sub_nonrefs {
	jint	icount;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_ByteCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_ByteCode$sub_nonrefs	soot_coffi_ByteCode;
};

// Object instance structure
struct _jc_soot_coffi_ByteCode$object {
	_jc_soot_coffi_ByteCode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_ByteCode$vtype	*vtype;
	_jc_soot_coffi_ByteCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_ByteCode$vtype _jc_soot_coffi_ByteCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_ByteCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_ByteCode$class_object;

#endif	/* _JC_soot_coffi_ByteCode_H_ */
